<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>AbortedByUserError</name>
    <message>
        <location filename="src/errors.py" line="43"/>
        <source>The user aborted the current action.</source>
        <translation>Пользователь прервал выполнение операции.</translation>
    </message>
</context>
<context>
    <name>ContentError</name>
    <message>
        <location filename="src/errors.py" line="55"/>
        <source>Could not open file because its contents are invalid, or written in a way not supported by OpenTeacher.</source>
        <translation>Невозможно открыть файл, поскольку он неисправен или не поддерживается OpenTeacher.</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="ui/about.ui" line="14"/>
        <source>About OpenTeacher</source>
        <translation>О программе OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="28"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="106"/>
        <source>License</source>
        <translation>Лицензионное соглашение</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="169"/>
        <source>Full license text</source>
        <translation>Полный текст лицензионного соглашения</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="195"/>
        <source>Authors</source>
        <translation>Разработчики</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="208"/>
        <source>Name</source>
        <translation>Имена</translation>
    </message>
    <message>
        <location filename="ui/wrtsLogin.ui" line="13"/>
        <source>WRTS - login please:</source>
        <translation>WRTS - вход в систему</translation>
    </message>
    <message>
        <location filename="ui/wrtsLogin.ui" line="22"/>
        <source>E-mail</source>
        <translation>Эл. почта</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="199"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="14"/>
        <source>OpenTeacher - Settings</source>
        <translation>Настройки OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="24"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="32"/>
        <source>Language:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="44"/>
        <source>Show &apos;overwrite&apos;-dialogs</source>
        <translation>Показывать окно &quot;Перезаписать&quot;</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="57"/>
        <source>Show &apos;do you want to save&apos;-dialogs</source>
        <translation>Показывать окно &quot;Вы хотите сохранить изменения?&quot;</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="70"/>
        <source>Lesson</source>
        <translation>Урок</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="76"/>
        <source>Show &apos;stop lesson&apos;-dialogs</source>
        <translation>Показывать окно &quot;Прервать обучение&quot;</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="86"/>
        <source>Show &apos;lesson completed&apos;-dialogs</source>
        <translation>Показывать окно &quot;Урок завершен&quot;</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="98"/>
        <source>Fade duration when wrong:</source>
        <translation>Продолжительность затемнения при неверном ответе</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="155"/>
        <source>milliseconds</source>
        <translation>миллисекунд</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="133"/>
        <source>Repeat mode hint duration:</source>
        <translation>Продолжительность затемнения подсказки:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="168"/>
        <source>Note notation:</source>
        <translation>Система оценки:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="183"/>
        <source>WRTS</source>
        <translation>WRTS</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="189"/>
        <source>Username:</source>
        <translation>Пользователь:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="213"/>
        <source>Try to connect to WRTS</source>
        <translation>Подключиться к WRTS</translation>
    </message>
    <message>
        <location filename="ui/about.ui" line="216"/>
        <source>Thanks to all Launchpad contributors!</source>
        <translation>Спасибо всем участникам Launchpad!</translation>
    </message>
    <message>
        <location filename="ui/wrtsListChoice.ui" line="14"/>
        <source>Choose WRTS list:</source>
        <translation>Выберите список WRTS:</translation>
    </message>
    <message>
        <location filename="ui/settings.ui" line="230"/>
        <source>Special Characters</source>
        <translation>Специальные символы</translation>
    </message>
</context>
<context>
    <name>DocumentationDialog</name>
    <message>
        <location filename="src/openteacher.py" line="356"/>
        <source>Documentation</source>
        <translation>Руководство пользователя</translation>
    </message>
</context>
<context>
    <name>InputEmptyError</name>
    <message>
        <location filename="src/errors.py" line="59"/>
        <source>There seems to be no content in the input area</source>
        <translation>Похоже, что Вы не ввели данные</translation>
    </message>
</context>
<context>
    <name>InputFormatError</name>
    <message>
        <location filename="src/errors.py" line="63"/>
        <source>There seems to be something wrong with the default input formatting (question = answer)</source>
        <translation>Похоже, что возникли проблемы с форматом вводимых данных (вопрос = ответ)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="ui/openteacher.ui" line="14"/>
        <source>OpenTeacher</source>
        <translation>OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="38"/>
        <source>Enter list</source>
        <translation>Список слов</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="68"/>
        <source>Title:</source>
        <translation>Название списка:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="81"/>
        <source>Question Language:</source>
        <translation>Язык (вопросов):</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="94"/>
        <source>Answer Language:</source>
        <translation>Язык (ответов):</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="874"/>
        <source>Symbols</source>
        <translation>Символы</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="915"/>
        <source>Greek</source>
        <translation>Греческие буквы</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="269"/>
        <source>Click here to enter the words in the textfield into the wordlisttable.</source>
        <translation>Введите новые слова и нажмите здесь, чтобы добавить их в таблицу изучаемых слов.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="272"/>
        <source>Enter!</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="275"/>
        <source>Ctrl+Return</source>
        <translation>Ctrl+Return</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="297"/>
        <source>Remove selected row(s)</source>
        <translation>Удалить выделенные строки</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="300"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="330"/>
        <source>Teach me!</source>
        <translation>Начать обучение</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="357"/>
        <source>Question Order:</source>
        <translation>Порядок вопросов:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="365"/>
        <source>Known-Foreign</source>
        <translation>Известные - Изучаемые</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="370"/>
        <source>Foreign-Known</source>
        <translation>Изучаемые - Известные</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="378"/>
        <source>Lesson Type:</source>
        <translation>Тип урока:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="386"/>
        <source>Ask smart (ideal for practising)</source>
        <translation>Умный опрос (отлично подходит для практики)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="396"/>
        <source>Ask until all answered right</source>
        <translation>Спрашивать до тех пор, пока все ответы не будут верны</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="401"/>
        <source>Ask all once</source>
        <translation>Спрашивать все вопросы по 1 разу</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="409"/>
        <source>Lesson Order:</source>
        <translation>Порядок проведения урока:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="417"/>
        <source>Random</source>
        <translation>Случайный</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="422"/>
        <source>Normal</source>
        <translation>Обычный</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="427"/>
        <source>Reverse</source>
        <translation>Обратный</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="432"/>
        <source>Sorted (ascending)</source>
        <translation>Упорядоченный (по возрастанию)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="437"/>
        <source>Sorted (descending)</source>
        <translation>Упорядоченный (по убыванию)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="445"/>
        <source>Ask Words:</source>
        <translation>Опрашивать слова:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="453"/>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="458"/>
        <source>Words you never answered correctly</source>
        <translation>Только те, на которые ни разу правильно не ответили</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="463"/>
        <source>Hard Words (&gt;50% errors)</source>
        <translation>Сложные (более 50% ошибок)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="508"/>
        <source>Word:</source>
        <translation>Слово:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="564"/>
        <source>Type Answer</source>
        <translation>Письменный ответ</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="815"/>
        <source>Translation:</source>
        <translation>Перевод:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="785"/>
        <source>Click here to check if your answer is right.</source>
        <translation>Нажмите здесь, чтобы проверить ответ.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="788"/>
        <source>Check!</source>
        <translation>Проверить</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="791"/>
        <source>Return</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="798"/>
        <source>Click here to correct the last checked answer anyway.</source>
        <translation>Если Вы хотите исправить ответ, нажмите здесь.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="801"/>
        <source>Correct anyway</source>
        <translation>Исправить</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="644"/>
        <source>Click here to view the answer of the current showed question.</source>
        <translation>Чтобы увидеть ответ, нажмите здесь.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="647"/>
        <source>View answer</source>
        <translation>Просмотреть ответ</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="660"/>
        <source>Click here if the answer matches to what you were thinking.</source>
        <translation>Нажмите здесь, если Вы правильно подумали.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="663"/>
        <source>I was right</source>
        <translation>Я был прав</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="670"/>
        <source>Click here if the answer doesn&apos;t match with what you were thinking.</source>
        <translation>Нажмите здесь, если вы ошиблись.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="673"/>
        <source>I was wrong</source>
        <translation>Я ошибся</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="681"/>
        <source>Shuffle answer</source>
        <translation>Перемешанные буквы</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="766"/>
        <source>Hint:</source>
        <translation>Подсказка:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="755"/>
        <source>Repeat answer</source>
        <translation>Повторить ответ</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="808"/>
        <source>Start!</source>
        <translation>Начать</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1022"/>
        <source>Total Questions:</source>
        <translation>Всего вопросов:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1057"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1036"/>
        <source>Right Answers:</source>
        <translation>Правильных ответов:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1050"/>
        <source>Note:</source>
        <translation>Оценка:</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1093"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1097"/>
        <source>&amp;Export</source>
        <translation>&amp;Экспорт</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1107"/>
        <source>Import</source>
        <translation>Импортировать</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1130"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1137"/>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1148"/>
        <source>toolBar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1175"/>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1178"/>
        <source>Open an existing file.</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1181"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1190"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1193"/>
        <source>Save the current opened file.</source>
        <translation>Сохранить текущий файл.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1196"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1205"/>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1208"/>
        <source>Close OpenTeacher.</source>
        <translation>Закрыть OpenTeacher</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1211"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1220"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1223"/>
        <source>View information about OpenTeacher.</source>
        <translation>Просмотреть информацию о программе.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1232"/>
        <source>Save &amp;As</source>
        <translation>Сохранить &amp;как</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1235"/>
        <source>Save the current opened file under a different name.</source>
        <translation>Сохранить текущий файл под другим именем</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1238"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1247"/>
        <source>&amp;New</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1250"/>
        <source>New</source>
        <translation>Новый</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1253"/>
        <source>Open a new, empty file.</source>
        <translation>Создать новый файл</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1256"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1277"/>
        <source>WRTS (online)</source>
        <translation>WRTS (он-лайн)</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1268"/>
        <source>Import a wordlist from your online WRTS-account.</source>
        <translation>Импортировать список слов из аккаунта WRTS.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1280"/>
        <source>Export the current opened wordlist to your online WRTS-account.</source>
        <translation>Экспортировать текущий список слов в WRTS.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1292"/>
        <source>Print the current opened file.</source>
        <translation>Распечатать текущий файл.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1295"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1304"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="956"/>
        <source>Cyrillic</source>
        <translation>Кириллица</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1289"/>
        <source>&amp;Print</source>
        <translation>&amp;Печать</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1313"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Руководство пользователя</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="391"/>
        <source>Interval training</source>
        <translation>Обучение с интервалом</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="1316"/>
        <source>Documentation</source>
        <translation>Руководство пользователя</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="844"/>
        <source>Change lesson settings</source>
        <translation>Изменить настройки урока</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="484"/>
        <source>Back to the lesson</source>
        <translation>Вернуться к уроку</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="294"/>
        <source>Click here to remove the selected row(s) from the word list table.</source>
        <translation>Нажмите здесь чтобы удалить выбранные столбцы из таблицы со списком слов.</translation>
    </message>
    <message>
        <location filename="ui/openteacher.ui" line="628"/>
        <source>Think answer</source>
        <translation>Подумайте над ответом</translation>
    </message>
</context>
<context>
    <name>NoEqualsSignInInputError</name>
    <message>
        <location filename="src/errors.py" line="79"/>
        <source>One or more lines could not be added (did they contain a = character?)</source>
        <translation>Строка(и) не могут быть добавлены (проверьте формат &quot;слово1 = слово2&quot;)</translation>
    </message>
</context>
<context>
    <name>NoWordsEnteredError</name>
    <message>
        <location filename="src/errors.py" line="91"/>
        <source>You didn&apos;t enter any words! Enter them and try again.</source>
        <translation>Вы не добавили ни одного слова! Введите слова и попробуйте еще раз.</translation>
    </message>
</context>
<context>
    <name>NoWordsLeftError</name>
    <message>
        <location filename="src/errors.py" line="87"/>
        <source>After filtering the wordlist, no words where left. Adjust the filter.</source>
        <translation>После фильтрации списка не осталось слов для изучения. Настройте фильтры (&quot;Тип урока&quot;, &quot;Порядок&quot; и т.д.)</translation>
    </message>
</context>
<context>
    <name>NotEnoughMetadataError</name>
    <message>
        <location filename="src/errors.py" line="75"/>
        <source>Please fill in the wordlist title, question language and answer language first. Then try again.</source>
        <translation>Пожалуйста, сначала заполните поля &quot;название списка&quot;, &quot;язык (вопросов)&quot; и &quot;язык (ответов)&quot;. Затем попробуйте снова.</translation>
    </message>
</context>
<context>
    <name>OpenError</name>
    <message>
        <location filename="src/errors.py" line="51"/>
        <source>Could not open file. Please check that you have permission to read this file.</source>
        <translation>Невозможно открыть файл. Убедитесь, что у Вас есть права на чтение этого файла.</translation>
    </message>
</context>
<context>
    <name>OpenTeacher</name>
    <message>
        <location filename="src/openteacher.py" line="220"/>
        <source>Code</source>
        <translation>Код</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="225"/>
        <source>Localisation</source>
        <translation>Локализация</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="319"/>
        <source>License</source>
        <translation>Лицензионное соглашение</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1250"/>
        <source>No selection was detected.</source>
        <translation>Сначала выделите ряды со словами.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1530"/>
        <source>Correct answer</source>
        <translation>Правильный ответ</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1625"/>
        <source>Translation: </source>
        <translation>Перевод:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1634"/>
        <source>Think about the answer, and press the &apos;View answer&apos; button when you&apos;re done.</source>
        <translation>Подумайте над ответом и, когда будете готовы, нажмите кнопку &quot;Просмотреть ответ&quot;.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1733"/>
        <source>Hint:</source>
        <translation>Подсказка:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1726"/>
        <source>Click the button to start.</source>
        <translation>Чтобы начать, нажмите эту кнопку.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1788"/>
        <source>Test completed!</source>
        <translation>Обучение завершено.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1788"/>
        <source>Test completed! Your note:</source>
        <translation>Урок закончен! Ваша оценка:</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1940"/>
        <source>Message</source>
        <translation>Сообщение</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1940"/>
        <source>Do you want to save changes?</source>
        <translation>Вы хотите сохранить изменения?</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1960"/>
        <source>Exit lesson</source>
        <translation>Выйти из урока</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1960"/>
        <source>Are you sure you want to stop the lesson?</source>
        <translation>Вы действительно хотите остановить урок?</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2004"/>
        <source>Supported</source>
        <translation>Поддерживаемые</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2083"/>
        <source>Plain text</source>
        <translation>Обычный текст</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2098"/>
        <source>Save...</source>
        <translation>Сохранить...</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2240"/>
        <source>Print Document</source>
        <translation>Распечатать документ</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2292"/>
        <source>Error</source>
        <translation>Oшибка</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="267"/>
        <source>OpenTeacher authors</source>
        <translation>Авторы OpenTeacher</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1211"/>
        <source>The word(s) were entered successfully.</source>
        <translation>Слова успешно добавлены.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1247"/>
        <source>The word(s) were removed successfully.</source>
        <translation>Слова успешно удалены.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1888"/>
        <source>The wordlist from WRTS was imported successfully.</source>
        <translation>Список слов успешно загружен из WRTS.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1918"/>
        <source>Export successful</source>
        <translation>Экспорт прошел успешно</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1919"/>
        <source>Word list exported to WRTS.</source>
        <translation>Список слов экспортирован в WRTS.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="1994"/>
        <source>New file created.</source>
        <translation>Новый файл создан.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2022"/>
        <source>The selected file was opened successfully.</source>
        <translation>Выбранный файл успешно открыт.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2165"/>
        <source>File saved.</source>
        <translation>Файл сохранён.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2246"/>
        <source>The file was printed successfully.</source>
        <translation>Файл успешно распечатан.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="267"/>
        <source>Project website</source>
        <translation>Сайт проекта</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="264"/>
        <source>OpenTeacher helps you learn a foreign language vocabulary.</source>
        <translation>OpenTeacher - программа, которая поможет Вам увеличить словарный запас изучаемого языка.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>een = one</source>
        <translation>один = one</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>twee = two</source>
        <translation>два = two</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="996"/>
        <source>drie = three</source>
        <translation>три = three</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>This credentials are saved in plain text on your harddrive.</source>
        <translation>Эти сведения будут сохранены на вашем компьютере в формате обычного текста.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="384"/>
        <source>Don&apos;t use this function on a public computer!</source>
        <translation>Не используйте эту опцию на компьютерах с публичным доступом!</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="2004"/>
        <source>Open...</source>
        <translation>Открыть…</translation>
    </message>
</context>
<context>
    <name>OpenTeacherError</name>
    <message>
        <location filename="src/errors.py" line="35"/>
        <source>Error</source>
        <translation>Oшибка</translation>
    </message>
</context>
<context>
    <name>QDialogButtonBox</name>
    <message>
        <location filename="src/openteacher.py" line="201"/>
        <source>Close without Saving</source>
        <translation>Закрыть без сохранения</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="188"/>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="190"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Отменить</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="196"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="192"/>
        <source>&amp;Yes</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="193"/>
        <source>&amp;No</source>
        <translation>&amp;Нет</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="187"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="189"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="195"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="197"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="198"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="199"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="202"/>
        <source>Don&apos;t save</source>
        <translation>Не сохранять</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="203"/>
        <source>Discard</source>
        <translation>Не сохранять</translation>
    </message>
</context>
<context>
    <name>QShortcut</name>
    <message>
        <location filename="src/openteacher.py" line="206"/>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="207"/>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="208"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="209"/>
        <source>Shift</source>
        <translation>Shift</translation>
    </message>
</context>
<context>
    <name>SaveError</name>
    <message>
        <location filename="src/errors.py" line="71"/>
        <source>Could not save file. Please check that the filename is correct and that you have permission to write to the save location.</source>
        <translation>Невозможно сохранить файл. Пожалуйста, проверьте название файла и права на запись в данную папку.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="src/openteacher.py" line="526"/>
        <source>Restart please</source>
        <translation>Перезапустите программу.</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="497"/>
        <source>Connection to WRTS failed</source>
        <translation>Не удалось подключиться к WRTS</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="500"/>
        <source>Connection to WRTS succeeded</source>
        <translation>Успешно подключён к WRTS</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="526"/>
        <source>You changed the language. In order to use the newly selected language, you need to restart OpenTeacher.</source>
        <translation>Вы изменили язык. Для того, чтобы использовать выбранный Вами язык, нужно перезапустить OpenTeacher.</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="src/openteacher.py" line="411"/>
        <source>Make your choice</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="412"/>
        <source>System default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="460"/>
        <source>Make your choice (all examples are good to bad)</source>
        <translation>Выбрать (каждая система оценки упорядочена по убыванию)</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="461"/>
        <source>Percents</source>
        <translation>Процентная</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="462"/>
        <source>Dutch</source>
        <translation>Голландская</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="463"/>
        <source>American</source>
        <translation>Американская</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="464"/>
        <source>German</source>
        <translation>Немецкая</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="465"/>
        <source>French</source>
        <translation>Французская</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="466"/>
        <source>ECTS</source>
        <translation>ECTS</translation>
    </message>
</context>
<context>
    <name>UnsupportedFileExportError</name>
    <message>
        <location filename="src/errors.py" line="67"/>
        <source>Could not save file. Please specify a valid file extension.</source>
        <translation>Не удалось сохранить файл. Пожалуйста, выберите правильное расширение файла.</translation>
    </message>
</context>
<context>
    <name>UnsupportedFileImportError</name>
    <message>
        <location filename="src/errors.py" line="47"/>
        <source>File couldn&apos;t be opened. Unsupported extension.</source>
        <translation>Невозможно открыть файл. Неподдерживаемое расширение.</translation>
    </message>
</context>
<context>
    <name>WordListTableModel</name>
    <message>
        <location filename="src/openteacher.py" line="661"/>
        <source>Question</source>
        <translation>Вопрос</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="662"/>
        <source>Answer</source>
        <translation>Ответ</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="663"/>
        <source>Second Answer (optional)</source>
        <translation>Другой вариант (необязательно)</translation>
    </message>
    <message>
        <location filename="src/openteacher.py" line="664"/>
        <source>Errors</source>
        <translation>Ошибки</translation>
    </message>
</context>
<context>
    <name>WrtsConnectionError</name>
    <message>
        <location filename="src/errors.py" line="83"/>
        <source>WRTS didn&apos;t accept the connection. Are you sure that your internet connection works and WRTS is online?</source>
        <translation>Не возможно подключиться к WRTS. Убедитесь, что у Вас работает Интернет и что WRTS сейчас доступен.</translation>
    </message>
</context>
<context>
    <name>WrtsLoginError</name>
    <message>
        <location filename="src/errors.py" line="39"/>
        <source>WRTS didn&apos;t accept the login credentials. Are you sure you entered your e-mail and password correctly?</source>
        <translation>WRTS не принял Ваши данные. А правильно ли Вы ввели адрес эл. почты и пароль?</translation>
    </message>
</context>
</TS>
